@@ -857,12 +857,10 @@ deal_with_x_crashes (GdmDisplay *d)
 	    if (pid == 0) {
 		    char *argv[2];
 		    char *xlog = g_strconcat (GdmLogDir, "/", d->name, ".log", NULL);
-		    int ii;
 
 		    closelog ();
 
-		    for (ii = 0; ii < sysconf (_SC_OPEN_MAX); ii++)
-			    close (ii);
+		    gdm_close_all_descriptors (0 /* from */, -1 /* except */);
 
 		    /* No error checking here - if it's messed the best response
 		    * is to ignore & try to continue */
@@ -1362,6 +1360,29 @@ linux_only_is_running (pid_t pid)
 	return FALSE;
 }
 
+static void
+ensure_desc_012 (void)
+{
+	int fd;
+	/* We here ensure descriptors 0, 1 and 2
+	 * we of course count on the fact that open
+	 * opens the lowest available descriptor */
+	for (;;) {
+		fd = open("/dev/null", O_RDWR);
+		/* what to do on fail?  I dunno,
+		 * just keep on going is the safest
+		 * bet I suppose */
+		if (fd < 0)
+			break;
+		/* Once we are up to 3, we're beyond stdin,
+		 * stdout and stderr */
+		if (fd >= 3) {
+			close (fd);
+			break;
+		}
+	}
+}
+
 int 
 main (int argc, char *argv[])
 {
@@ -1371,6 +1392,9 @@ main (int argc, char *argv[])
     poptContext ctx;
     int nextopt;
 
+    /* We here ensure descriptors 0, 1 and 2 */
+    ensure_desc_012 ();
+
     store_argv (argc, argv);
 
     bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
