@@ -44,6 +44,9 @@
 #include <fcntl.h>
 #include <sys/ioctl.h>
 #include <net/if.h>
+#ifdef HAVE_SYS_SOCKIO_H
+#include <sys/sockio.h>
+#endif
 
 #include <viciousui.h>
 
@@ -79,6 +82,7 @@ static gchar *client_address = NULL;
 static gint connection_type = 0;
 
 static void gdm_chooser_abort (const gchar *format, ...) G_GNUC_PRINTF (1, 2);
+static void gdm_chooser_warn (const gchar *format, ...) G_GNUC_PRINTF (1, 2);
 
 /* Exported for glade */
 gboolean gdm_chooser_cancel (void);
@@ -148,6 +152,14 @@ static GdkPixbuf *defhostimg;
 static GtkWidget *browser;
 static GdmChooserHost *curhost;
 
+static void
+setup_cursor (GdkCursorType type)
+{
+	GdkCursor *cursor = gdk_cursor_new (type);
+	gdk_window_set_cursor (GDK_ROOT_PARENT (), cursor);
+	gdk_cursor_destroy (cursor);
+}
+
 static void
 gdm_chooser_host_dispose (GdmChooserHost *host)
 {
@@ -415,14 +427,15 @@ gdm_chooser_find_bcaddr (void)
 #endif
 
 	ifc.ifc_len = sizeof (struct ifreq) * num;
-	ifc.ifc_buf = buf = g_malloc (ifc.ifc_len);
+	ifc.ifc_buf = buf = g_malloc0 (ifc.ifc_len);
 	if (ioctl (sockfd, SIOCGIFCONF, &ifc) < 0) {
 		g_free (buf);
-		gdm_chooser_abort ("Cannot get local addresses!");
+		gdm_chooser_warn ("Cannot get local addresses!");
 		return;
 	}
 
 	ifr = ifc.ifc_req;
+	num = ifc.ifc_len / sizeof(struct ifreq);
 	for (i = 0 ; i < num ; i++) {
 		if ( ! ve_string_empty (ifr[i].ifr_name)) {
 			struct ifreq ifreq;
@@ -436,7 +449,7 @@ gdm_chooser_find_bcaddr (void)
 			ifreq.ifr_name[sizeof (ifreq.ifr_name) - 1] = '\0';
 
 			if (ioctl (sockfd, SIOCGIFFLAGS, &ifreq) < 0) 
-				gdm_chooser_abort ("Could not get SIOCGIFFLAGS for %s", ifr[i].ifr_name);
+				gdm_chooser_warn ("Could not get SIOCGIFFLAGS for %s", ifr[i].ifr_name);
 
 			if ((ifreq.ifr_flags & IFF_UP) == 0 ||
 			    (ifreq.ifr_flags & IFF_BROADCAST) == 0 ||
@@ -635,6 +648,8 @@ gdm_chooser_xdmcp_init (char **hosts)
     gdm_chooser_add_hosts (hosts);
 
     channel = g_io_channel_unix_new (sockfd);
+    g_io_channel_set_encoding (channel, NULL, NULL);
+    g_io_channel_set_buffered (channel, FALSE);
     g_io_add_watch_full (channel, G_PRIORITY_DEFAULT,
 			G_IO_IN|G_IO_PRI|G_IO_ERR|G_IO_HUP|G_IO_NVAL,
 			gdm_chooser_decode_packet,
@@ -650,7 +665,8 @@ gdm_chooser_choose_host (const char *hostname)
   ARRAY8 tmparr;
   struct hostent *hentry;
 
-  g_print ("%s\n", curhost->name);
+  printf ("%s\n", curhost->name);
+  fflush (stdout);
   if (xdm_address != NULL) {
       struct sockaddr_in in_addr;
       char xdm_addr[32];
@@ -743,14 +759,29 @@ gdm_chooser_abort (const gchar *format, ...)
     exit (EXIT_FAILURE);
 }
 
+static void
+gdm_chooser_warn (const gchar *format, ...)
+{
+    va_list args;
+    gchar *s;
+
+    va_start (args, format);
+    s = g_strdup_vprintf (format, args);
+    va_end (args);
+
+    syslog (LOG_ERR, "%s", s);
+    closelog ();
+}
+
 
 static void 
 gdm_chooser_parse_config (void)
 {
+    /* stupid, or is it?
     struct stat unused;
-	
     if (stat (GDM_CONFIG_FILE, &unused) == -1)
 	gdm_chooser_abort (_("gdm_chooser_parse_config: No configuration file: %s. Aborting."), GDM_CONFIG_FILE);
+	*/
 
     gnome_config_push_prefix ("=" GDM_CONFIG_FILE "=/");
 
@@ -896,10 +927,17 @@ gdm_chooser_gui_init (void)
 	gtk_rc_parse (GdmGtkRC);
 
     /* Load default host image */
-    if (access (GdmHostDefaultIcon, R_OK) != 0)
-	gdm_chooser_abort (_("Can't open default host icon: %s"), GdmHostDefaultIcon);
-    else
+    if (access (GdmHostDefaultIcon, R_OK) != 0) {
+	gdm_chooser_warn (_("Can't open default host icon: %s"), GdmHostDefaultIcon);
+	/* bogus image */
+	defhostimg = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
+				     FALSE /* has_alpha */,
+				     8 /* bits_per_sample */,
+				     48 /* width */,
+				     48 /* height */);
+    } else {
 	defhostimg = gdk_pixbuf_new_from_file (GdmHostDefaultIcon, NULL);
+    }
 
     /* Main window */
     chooser_app = glade_helper_load ("gdmchooser.glade",
@@ -1010,11 +1048,17 @@ gdm_event (GSignalInvocationHint *ihint,
 	   const GValue	       *param_values,
 	   gpointer		data)
 {
+	GdkEvent *event;
+
 	/* HAAAAAAAAAAAAAAAAACK */
 	/* Since the user has not logged in yet and may have left/right
 	 * mouse buttons switched, we just translate every right mouse click
 	 * to a left mouse click */
-	GdkEvent *event = g_value_get_pointer ((GValue *)param_values);
+	if (n_param_values != 2 ||
+	    !G_VALUE_HOLDS (&param_values[1], GDK_TYPE_EVENT))
+	  return FALSE;
+	
+	event = g_value_get_boxed (&param_values[1]);
 	if ((event->type == GDK_BUTTON_PRESS ||
 	     event->type == GDK_2BUTTON_PRESS ||
 	     event->type == GDK_3BUTTON_PRESS ||
@@ -1028,12 +1072,10 @@ gdm_event (GSignalInvocationHint *ihint,
 int 
 main (int argc, char *argv[])
 {
-    char **fixedargv;
-    int fixedargc, i;
     char **hosts;
     poptContext ctx;
+    int nextopt;
     const char *gdm_version;
-    GnomeProgram *program;
 
     if (g_getenv ("DOING_GDM_DEVELOPMENT") != NULL)
 	    DOING_GDM_DEVELOPMENT = TRUE;
@@ -1042,32 +1084,29 @@ main (int argc, char *argv[])
 
     openlog ("gdmchooser", LOG_PID, LOG_DAEMON);
 
-    fixedargc = argc + 1;
-    fixedargv = g_new0 (gchar *, fixedargc);
-
-    for (i=0; i < argc; i++)
-	fixedargv[i] = argv[i];
-    
-    fixedargv[fixedargc-1] = "--disable-sound";
-
     bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     textdomain (GETTEXT_PACKAGE);
 
-    program = gnome_program_init ("gdmchooser", VERSION, 
-				  /* FIXME: oh fuck this inits way too much
-				   * shit that we don't want */
-				  LIBGNOMEUI_MODULE /* module_info */,
-				  fixedargc, fixedargv,
-				  GNOME_PARAM_POPT_TABLE, xdm_options,
-				  GNOME_PARAM_CREATE_DIRECTORIES, FALSE,
-				  NULL);
+    gtk_init (&argc, &argv);
 
-    g_object_get (G_OBJECT (program),
-		  GNOME_PARAM_POPT_CONTEXT, &ctx,
-		  NULL);
-    glade_gnome_init();
-    g_free (fixedargv);
+    ctx = poptGetContext ("gdm", argc, (const char **) argv,
+			  xdm_options, 0);
+    while ((nextopt = poptGetNextOpt (ctx)) > 0 || nextopt == POPT_ERROR_BADOPT)
+	/* do nothing */ ;
+
+    if (nextopt != -1) {
+	    g_print (_("Error on option %s: %s.\nRun '%s --help' to see a full list of available command line options.\n"),
+		     poptBadOption (ctx, 0),
+		     poptStrerror (nextopt),
+		     argv[0]);
+	    exit (1);
+    }
+
+    /* Should be a watch already, but just in case */
+    setup_cursor (GDK_WATCH);
+
+    glade_init();
 
     gdm_chooser_parse_config();
 
@@ -1096,6 +1135,8 @@ main (int argc, char *argv[])
 	    gtk_widget_show_all (dialog);
 	    gdm_wm_center_window (GTK_WINDOW (dialog));
 
+	    setup_cursor (GDK_LEFT_PTR);
+
 	    gtk_dialog_run (GTK_DIALOG (dialog));
 
 	    return EXIT_SUCCESS;
@@ -1119,7 +1160,7 @@ main (int argc, char *argv[])
     gdm_chooser_xdmcp_init (hosts);
     poptFreeContext (ctx);
 
-    if (g_getenv ("RUNNING_UNDER_GDM") != NULL) {
+    if (RUNNING_UNDER_GDM) {
 	    guint sid = g_signal_lookup ("event",
 					 GTK_TYPE_WIDGET);
 	    g_signal_add_emission_hook (sid,
@@ -1129,8 +1170,11 @@ main (int argc, char *argv[])
 					NULL /* destroy_notify */);
     }
 
+    gtk_widget_queue_resize (chooser);
     gtk_widget_show_now (chooser);
 
+    gdm_wm_center_window (GTK_WINDOW (chooser));
+
     /* can it ever happen that it'd be NULL here ??? */
     if (chooser->window != NULL) {
 	    gdm_wm_init (GDK_WINDOW_XWINDOW (chooser->window));
@@ -1141,6 +1185,8 @@ main (int argc, char *argv[])
 	    gdm_wm_focus_window (GDK_WINDOW_XWINDOW (chooser->window));
     }
 
+    setup_cursor (GDK_LEFT_PTR);
+
     gtk_main();
 
     exit (EXIT_SUCCESS);
