@@ -50,6 +50,7 @@ gchar *GdmConfigurator = NULL;
 gboolean GdmSystemMenu = TRUE;
 gboolean GdmConfigAvailable = TRUE;
 gboolean GdmTimedLoginEnable;
+gboolean GdmUse24Clock;
 gchar *GdmTimedLogin;
 gint GdmTimedLoginDelay;
 
@@ -133,7 +134,9 @@ greeter_parse_config (void)
 	GdmTimedLoginDelay = 5;
       }
     greeter_current_delay = GdmTimedLoginDelay;
-    
+
+    GdmUse24Clock = gnome_config_get_bool (GDM_KEY_USE_24_CLOCK);
+
     gnome_config_pop_prefix();
 
     if (GdmXineramaScreen < 0)
@@ -501,6 +504,14 @@ greeter_setup_items (void)
   greeter_item_session_setup ();
 }
 
+static void
+setup_cursor (GdkCursorType type)
+{
+	GdkCursor *cursor = gdk_cursor_new (type);
+	gdk_window_set_cursor (GDK_ROOT_PARENT (), cursor);
+	gdk_cursor_destroy (cursor);
+}
+
 enum {
 	RESPONSE_RESTART,
 	RESPONSE_REBOOT,
@@ -541,6 +552,8 @@ verify_gdm_version (void)
     
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
+
+      setup_cursor (GDK_LEFT_PTR);
     
       gtk_dialog_run (GTK_DIALOG (dialog));
     
@@ -575,6 +588,8 @@ verify_gdm_version (void)
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
       
+      setup_cursor (GDK_LEFT_PTR);
+
       switch (gtk_dialog_run (GTK_DIALOG (dialog)))
 	{
 	case RESPONSE_REBOOT:
@@ -621,6 +636,8 @@ verify_gdm_version (void)
     
       gtk_dialog_set_default_response (GTK_DIALOG (dialog), RESPONSE_RESTART);
       
+      setup_cursor (GDK_LEFT_PTR);
+
       switch (gtk_dialog_run (GTK_DIALOG (dialog)))
 	{
 	case RESPONSE_RESTART:
@@ -742,14 +759,6 @@ greeter_done (int sig)
 }
 
 
-static void
-setup_cursor (GdkCursorType type)
-{
-	GdkCursor *cursor = gdk_cursor_new (type);
-	gdk_window_set_cursor (GDK_ROOT_PARENT (), cursor);
-	gdk_cursor_destroy (cursor);
-}
-
 static char *
 get_theme_file (const char *in, char **theme_dir)
 {
@@ -851,7 +860,8 @@ main (int argc, char *argv[])
 
   gtk_init (&argc, &argv);
 
-  setup_cursor (GDK_LEFT_PTR);
+  /* Should be a watch already, but anyway */
+  setup_cursor (GDK_WATCH);
   
   gdm_wm_screen_init (GdmXineramaScreen);
   
@@ -893,6 +903,8 @@ main (int argc, char *argv[])
   
   if (! DOING_GDM_DEVELOPMENT) {
     ctrlch = g_io_channel_unix_new (STDIN_FILENO);
+    g_io_channel_set_encoding (ctrlch, NULL, NULL);
+    g_io_channel_set_buffered (ctrlch, FALSE);
     g_io_channel_init (ctrlch);
     g_io_add_watch (ctrlch, 
 		    G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP | G_IO_NVAL,
@@ -959,6 +971,8 @@ main (int argc, char *argv[])
     
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
+
+      setup_cursor (GDK_LEFT_PTR);
     
       gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -977,6 +991,8 @@ main (int argc, char *argv[])
     
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
+
+      setup_cursor (GDK_LEFT_PTR);
     
       gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -1018,6 +1034,8 @@ main (int argc, char *argv[])
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
 
+      setup_cursor (GDK_LEFT_PTR);
+
       gdm_wm_no_login_focus_push ();
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
@@ -1040,6 +1058,8 @@ main (int argc, char *argv[])
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
 
+      setup_cursor (GDK_LEFT_PTR);
+
       gdm_wm_no_login_focus_push ();
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
@@ -1064,6 +1084,8 @@ main (int argc, char *argv[])
       gtk_widget_show_all (dialog);
       gdm_wm_center_window (GTK_WINDOW (dialog));
 
+      setup_cursor (GDK_LEFT_PTR);
+
       gdm_wm_no_login_focus_push ();
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
@@ -1072,6 +1094,8 @@ main (int argc, char *argv[])
 
   gdm_wm_restore_wm_order ();
 
+  setup_cursor (GDK_LEFT_PTR);
+
   gtk_main ();
 
   return 0;
